@@ -63,7 +63,7 @@ from foundry.gui.ObjectStatusBar import ObjectStatusBar
 from foundry.gui.ObjectToolBar import ObjectToolBar
 from foundry.gui.ObjectViewer import ObjectViewer
 from foundry.gui.PaletteViewer import PaletteViewer, SidePalette
-from foundry.gui.settings import SETTINGS, save_settings
+from foundry.gui.settings import GUI_STYLE, SETTINGS, save_settings
 from foundry.gui.SettingsDialog import POWERUPS, SettingsDialog
 from foundry.gui.SpinnerPanel import SpinnerPanel
 from foundry.gui.Toolbar import create_toolbar
@@ -111,7 +111,11 @@ class MainWindow(QMainWindow):
         super(MainWindow, self).__init__()
 
         self.setWindowIcon(icon(main_window_flags["icon"]))
-        self.setStyleSheet(SETTINGS[main_window_flags["style"]])
+        try:
+            GUI_STYLE[SETTINGS["gui_style"]](self)
+        except KeyError:
+            SETTINGS["gui_style"] = "LIGHT BLUE"
+            GUI_STYLE[SETTINGS["gui_style"]]
 
         setup_window(self, main_window_flags)
 
@@ -170,7 +174,7 @@ class MainWindow(QMainWindow):
         splitter.setOrientation(Qt.Vertical)
 
         splitter.addWidget(self.object_list)
-        splitter.setStretchFactor(0, 1)
+        splitter.setStretchFactor(1, 1)
         splitter.addWidget(self.jump_list)
         splitter.addWidget(JumpCreator(parent=self, level_view=self.level_view))
 
@@ -1067,7 +1071,9 @@ class MainWindow(QMainWindow):
     def on_jump_edit(self):
         index = self.jump_list.currentIndex().row()
 
-        updated_jump = JumpEditor.edit_jump(self, self.level_view.level_ref.jumps[index])
+        updated_jump = JumpEditor.edit_jump(
+            self, self.level_view.level_ref.jumps[index], not self.level_view.level_ref.level.is_vertical
+        )
 
         self.on_jump_edited(updated_jump)
 
