@@ -10,6 +10,7 @@ class ObjectList(QListWidget):
         super(ObjectList, self).__init__(parent=parent)
 
         self.setSizePolicy(QSizePolicy.Maximum, QSizePolicy.Maximum)
+        self.setSizeAdjustPolicy(QListWidget.AdjustToContents)
 
         self.setSelectionMode(self.ExtendedSelection)
 
@@ -44,7 +45,7 @@ class ObjectList(QListWidget):
             return super(ObjectList, self).mouseReleaseEvent(event)
 
     def on_right_down(self, event: QMouseEvent):
-        item_under_mouse = self.itemAt(event.position())
+        item_under_mouse = self.itemAt(event.pos())
 
         if item_under_mouse is None:
             event.ignore()
@@ -60,7 +61,7 @@ class ObjectList(QListWidget):
             self.level_ref.selected_objects = [selected_object]
 
     def on_right_up(self, event):
-        item_under_mouse = self.itemAt(event.position())
+        item_under_mouse = self.itemAt(event.pos())
 
         if item_under_mouse is None:
             event.ignore()
