@@ -11,7 +11,6 @@ from foundry.game.gfx.objects.LevelObject import LevelObject, get_minimal_icon_o
 from foundry.game.gfx.objects.LevelObjectFactory import LevelObjectFactory
 from foundry.game.gfx.Palette import bg_color_for_palette_group
 from foundry.smb3parse.objects import MAX_DOMAIN, MAX_ENEMY_ITEM_ID, MAX_ID_VALUE
-from foundry.smb3parse.objects.enemy_item import EnemyItem
 
 
 class ObjectIcon(QWidget):
@@ -21,7 +20,7 @@ class ObjectIcon(QWidget):
     clicked: SignalInstance = Signal()
     object_placed: SignalInstance = Signal()
 
-    def __init__(self, level_object: Optional[LevelObject] = None):
+    def __init__(self, level_object: Optional[Union[LevelObject, EnemyObject]] = None):
         super(ObjectIcon, self).__init__()
 
         size_policy = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
@@ -128,7 +127,7 @@ class ObjectToolBox(QWidget):
 
         self._layout.setAlignment(Qt.AlignHCenter)
 
-    def add_object(self, level_object: Union[EnemyItem, LevelObject], index: int = -1):
+    def add_object(self, level_object: Union[EnemyObject, LevelObject], index: int = -1):
         icon = ObjectIcon(level_object)
 
         icon.clicked.connect(self._on_icon_clicked)
